@@ -1,15 +1,16 @@
 #' Binning the Raw Data
 #'
-#' This function creates a binned data from a numeric vector
+#' This function creates a binned data set from the raw data
 #'
-#' Given a numeric vector, the function \code{bin} creates binned data with bin value provided
-#' by \code{brks}. Fitting mixture models with a large dataset may be slow, especially when
-#' we want to fit a mixture model outside of normal family. Binning the data with a relatively
-#' small binwidth speeds up the computation of EM algorithm while at the same time keeps the
+#' Given a numeric vector, the function \code{bin} creates a binned data set with bin values provided
+#' by \code{brks}. Fitting mixture models with a large data set may be slow, especially when
+#' we want to fit non-normal mixture models. Binning the data with a relatively
+#' small bin width speeds up the computation of EM algorithm while at the same time keeps the
 #' precision of the estimation result.
 #'
-#' @param x a numeric vector
-#' @param brks a numeric vector in increasing order, representing the value of each bin
+#' @param x a numeric vector of raw data
+#' @param brks a numeric vector in increasing order, representing the bin values within each of which 
+#' we want to calculate the frequency of the data
 #' @return The function \code{bin} returns a matrix with three columns, representing the value of the left bin, the value of the right bin and the number of observations in \code{x} that falls in each bin.
 #'
 #' @seealso \code{\link{reinstate}}
@@ -28,7 +29,7 @@ bin <- function(x, brks) {
 	colnames(res) <- c("a", "b", "freq")
 	res[,1] <- brks[-k]
 	res[,2] <- brks[-1]
-	temp <- .bincode(x, brks)
+	temp <- .bincode(x, brks, include.lowest = TRUE)
 	temp <- temp[!is.na(temp)]
 
 	for(i in 1:(k-1)) {
